function onRunAction(context) {
  if (!isFrameworkLoaded()) {
        const contentsPath = context.scriptPath.stringByDeletingLastPathComponent().stringByDeletingLastPathComponent();
        const resourcesPath = contentsPath.stringByAppendingPathComponent("Resources");

        const result = Mocha.sharedRuntime().loadFrameworkWithName_inDirectory("Instruments", resourcesPath);
        if (!result) {
            const alert = NSAlert.alloc().init();
            alert.alertStyle = NSAlertStyleCritical;
            alert.messageText = "Loading framework for “Instruments” failed";
            alert.informativeText = "Try exporting again and if the issue continues, contact us at support@zeplin.io.";

            alert.runModal();

            return;
        }
    }

    const actionDictionary = context["action"];
    const result = ZPLInstrumentsPluginController.runActionWithDictionary_command(actionDictionary, __command);

    const outputObject = {};
    if (result && result.logs.length > 0) {
        let fatalError;

        outputObject.logs = [];
        for (i = 0; i < result.logs.length; i++) {
            const { type, message, detail } = result.logs[i];

            outputObject.logs.push({
                type: `${type}`,
                message: `${message}`,
                detail: `${detail}`
            });

            if (type == "fatal") {
                fatalError = message;
            }
        }

        if (fatalError) {
            const alert = NSAlert.alloc().init();
            alert.alertStyle = NSAlertStyleCritical;
            alert.messageText = fatalError;
            alert.informativeText = "Try exporting again and if the issue continues, contact us at support@zeplin.io.";

            alert.runModal();
        }
    }

    if (Object.keys(outputObject).length > 0) {
        console.log(JSON.stringify(outputObject));
    }
}

function isFrameworkLoaded() {
    return Boolean(NSClassFromString("ZPLInstrumentsPluginController"));
}
